
/* 
   Project:     SOFTSUSY
   File:        def.h
   Author:      Ben Allanach 
   Manual:      hep-ph/0104145, Comp. Phys. Comm. 143 (2002) 305 
   Webpage:     http://allanach.home.cern.ch/allanach/softsusy.html
   Description: Contains switches and default parameters

   $Log: def.h,v $
   Revision 1.10  2002/09/03 14:16:44  allanach
   Taken PRINTOUT, MIXING, EPS out of def.h to make it quicker to compile once
   they are changed.

   Revision 1.9  2002/08/30 12:31:55  allanach
   Test RPV version that works!

   Revision 1.8  2002/07/30 12:57:31  allanach
   SOFTSUSY1.5

   Revision 1.7  2002/07/19 15:54:06  allanach
   SOFTSUSY1.5 version

   Revision 1.6  2002/06/14 16:26:30  allanach
   Switches included for 2-loop running of scalar masses, and calulating mt at mt.

   Revision 1.5  2002/04/18 14:32:05  allanach
   Changed RGEs and anomalous dimensions to be compatible with new notation;
   started implementation of rewsb in R-parity violation

   Revision 1.3  2002/04/12 06:24:50  allanach
   Code maintenance - returning a subobject made simpler

   Revision 1.6  2001/07/18 15:54:50  allanach
   Put MIXING switch into def.h

   Revision 1.5  2001/07/18 14:42:51  allanach
   Added proper header info
   */

#ifndef DEF_H
#define DEF_H

// Uncomment if you want to include the 2-loop scalar RGE corrections: 
// they slow it down by a factor of 3.
//#define INCLUDE_2_LOOP_SCALAR_CORRECTIONS
// uncomment if you want checking of vector/matrices bounds
#define ARRAY_BOUNDS_CHECKING 

const double EPSTOL = 1.0e-11;
const double PI = atan(1.0) * 4.0; // or 3.141592653589793 longhand;

// particle data book 2000 central values
const double GMU = 1.16637e-5;
const double MZ = 91.1882;
const double MW = 80.419;
const double ALPHAEM0 = 1.0 / 137.0359895; // hep-ph/9501277: update!

// default masses, running
const double MUP = 2.5e-3;
const double MDOWN = 0.006;
const double MSTRANGE = 0.1225;
const double MCHARM = 1.25;
const double MBOTTOM = 4.2;
const double MTOP = 165.0;
const double MELECTRON = 5.10998902e-4;
const double MMUON = 1.05658357e-1;
const double MTAU = 1.77703;
const double ALPHASMZ = 0.1181;
const double ALPHAMZ = 1.0 / 127.9;

// masses, pole
const double PMTOP = 173.8;
const double PMBOTTOM = 4.9;

// errors
const double SIGMABOTTOM = 0.20;
const double SIGMATOP = 5.1;
const double SIGMAALPHASMZ = 0.002;

// limits on particle masses
const double LOWER_TANB_HIGGS_BOUND = 99.8;
const double HIGHER_TANB_HIGGS_BOUND = 89.3;
// the following are collated in hep-ph/9907331
const double NEUTRALINO_BOUND = 37.0; // from ALEPH hep-ex/0011047
const double CHARGINO_BOUND = 104.0;
const double SNEUTRINO_BOUND = 43.1;
const double SLEPTON_BOUND = 80.0;
const double SQUARK_BOUND = 250.0;
const double STOP_BOUND = 83.0;
const double SBOTTOM_BOUND = 83.0;
const double GLUINO_BOUND = 300.0;

char * dir(char a[80]);

#endif
