
/* 
   Project:     SOFTSUSY 1.6
   File:        main.cpp
   Author:      Ben Allanach 
   Manual:      B.C. Allanach,hep-ph/0104145, Comp. Phys. Comm. 143 (2002) 305 
   Webpage:     http://allanach.home.cern.ch/allanach/softsusy.html
   Description: main calling program example
*/

#include "iostream.h"
#include "complex.h"
#include "def.h"
#include "linalg.h"
#include "lowe.h"
#include "rge.h"
#include "softsusy.h"
#include "softpars.h"
#include "susy.h"
#include "utils.h"
#include "numerics.h"

int MIXING, PRINTOUT;
double TOLERANCE;

int main() {
 // Sets format of output: 4 decimal places
  outputCharacteristics(4);

  cout << "SOFTSUSY1.6 test program, Ben Allanach 2002\n";
  cout << "If you use SOFTSUSY, please refer to B.C. Allanach, \n";
  cout << " Comput. Phys. Commun. 143 (2002) 305, hep-ph/0104145\n\n";

  // Parameters used
  double m12 = 250., a0 = -100., mgut = -1.0e16, tanb = 10.0, m0 = 100.;
  int sgnMu = 1;

  QedQcd oneset, twoset;
  readIn(oneset, "massIn");

  cout << "Low energy data in SOFTSUSY: MIXING=" << MIXING << " TOLERANCE=" 
       << TOLERANCE << endl << oneset << endl;

  oneset.toMz();

  MssmSoftsusy r; 
  DoubleVector pars(3); 
  pars(1) = m0; pars(2) = m12; pars(3) = a0;

  r.lowOrg(sugraBcs, mgut, pars, sgnMu, tanb, oneset);

  r.microMegasInterface("SoftSusyMicromegasInterface");
  r.isawigInterface751("SoftSusyIsawigOutput", "SoftSusySsrunInterface",
		    "SoftSusyIsawigInterface");
  r.ssrunInterface751("SoftSusySsrunOutput", "SoftSusySsrunInterface");
  r.isajetInterface751("SoftSusyIsajetInterface");

  cout << "mgut=" << mgut << endl << r;
  cout << "Fine-tuning " << r.fineTune(sugraBcs, pars, mgut);
}
