/*
   Project:     SOFTSUSY 
   File:        tensor.h
   Author:      Ben Allanach 
   Manual:      hep-ph/0104145, Comp. Phys. Comm. 143 (2002) 305 
   Webpage:     http://allanach.home.cern.ch/allanach/softsusy.html

   Contains all supersymmetric RPVMSSM parameters

   $Log: tensor.h,v $
   Revision 1.4  2002/05/23 21:33:40  allanach
   *** empty log message ***

   Revision 1.3  2002/04/15 09:09:04  allanach
   *** empty log message ***

   Revision 1.1  2002/04/11 10:23:26  allanach
   Seperated 3-index tensors into their own file
 */

#ifndef TENSOR_H
#define TENSOR_H

#include<iostream.h>
#include<math.h>
#include<fstream.h>
#include "linalg.h"
#include "rge.h"
#include "lowe.h"
#include "susy.h"

/* ----------- Tensor starts here ------------------- */
class Tensor;
ostream & operator <<(ostream &left, const Tensor &);

// Specifically: a vector of matrices, specially designed for R-parity
// violating interactions ie dimensions (3,3,3)
class Tensor
{
private:
  DoubleMatrix A1, A2, A3;
  
  void setTensor(const DoubleMatrix &, const DoubleMatrix &, const
		 DoubleMatrix &); 
  
public:
  Tensor();
  Tensor(const Tensor &);
  
  void threecheck(const DoubleMatrix &, const DoubleMatrix &, const DoubleMatrix &);
  
  double & operator () (int, int, int);
  DoubleMatrix & operator () (int);
  
  DoubleMatrix display(int) const;
  double display(int, int, int) const;
  void checkOut(double) const;
  void set(int, int, int, double);

  DoubleVector trace(int) const;
  Tensor transpose() const;
  DoubleMatrix dotProd(const DoubleVector &, int) const;
  Tensor operator*(double) const;
  Tensor operator/(double) const;
  Tensor operator*(const DoubleMatrix &) const;
  Tensor operator+(const Tensor &) const;
  Tensor operator-(const Tensor &) const;
  Tensor product(const DoubleMatrix &) const;
  Tensor swap(int);
  Tensor raise(const DoubleMatrix & M) const;
};

Tensor operator*(double, const Tensor &);
Tensor operator*(const DoubleMatrix &, const Tensor &);
Tensor outerProduct(const DoubleVector &, const DoubleMatrix &, int);
DoubleMatrix matrixify(const Tensor &, const Tensor &);
DoubleMatrix sumProd(const Tensor &, const Tensor &);

#endif
